--[[

$Revision: 70437 $

(C) Copyright 2007 Bethink (bethink at naef dot com)

This file is part of Analyst.

Analyst is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Analyst is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Leser General Public License
along with Analyst. If not, see <http://www.gnu.org/licenses/>.

]]


----------------------------------------------------------------------
-- Acquire libraries and declare add-on

local L = AceLibrary("AceLocale-2.2"):new("Analyst")
Analyst = AceLibrary("AceAddon-2.0"):new(
	"AceConsole-2.0",
	"AceDB-2.0",
	"AceDebug-2.0",
	"AceEvent-2.0",
	"AceHook-2.1",
	"FuBarPlugin-2.0")

	
----------------------------------------------------------------------
-- Constants

-- Chat options
local ACE_OPTS = {
	type = "group",
	args = {
		economy = {
			type = "toggle",
			name = L["ECONOMY"],
			desc = L["ECONOMY_DESC"],
			get = "IsEconomyFrameShown",
			set = "ToggleEconomyFrame"
		},
		startDayOfWeek = {
			type = "range",
			name = L["START_DAY_OF_WEEK"],
			desc = L["START_DAY_OF_WEEK_DESC"],
			min = 1,
			max = 7,
			step = 1,
			get = "GetStartDayOfWeek",
			set = "SetStartDayOfWeek"
		}
	}
}

-- Database version
ANALYST_DATABASE_VERSION = 1

-- Data lifetime
ANALYST_DATA_LIFETIME = 30

-- Bindings
BINDING_HEADER_ANALYST = L:GetTranslation("BINDING_HEADER_ANALYST")
BINDING_NAME_ECONOMY = L:GetTranslation("BINDING_NAME_ECONOMY")


----------------------------------------------------------------------
-- Core handlers

-- One-time initialization
function Analyst:OnInitialize()
	-- Registrations
	self:RegisterDB("AnalystDB", "AnalystDBPerChar")
	self:RegisterChatCommand(L["SLASH_COMMANDS"], ACE_OPTS)

	-- Initialize debuggign
	self:SetDebugging(false)
	self:SetDebugLevel(2)
	
	-- Uncomment below for debugging from the start
	--self:SetDebugging(true)
		
	-- Uncomment below for verbose debugging
	--self:SetDebugLevel(3)

	-- Defaults
	self:RegisterDefaults("account", {
		startDayOfWeek = 1
	})
	
	-- Database version
	self.db.account.databaseVersion = DATABASE_VERSION
	
	-- FuBar
	self.OnMenuRequest = ACE_OPTS
	self.hasIcon = true
	self:SetIcon("Interface\\Icons\\INV_Misc_Spyglass_03.blp")
	
	-- Subsystems
	self:InitializeCapture()
	self:InitializeMeasure()
	self:InitializeVendorValue()
	self:InitializeEconomyFrame()
end

-- Handles (re-)enabling of the addon
function Analyst:OnEnable ()
	-- Events
	self:RegisterEvent("PLAYER_LOGIN")
	self:RegisterEvent("PLAYER_LOGOUT")

	-- Subsystems
	self:EnableCapture()
	self:EnableMeasure()
	self:EnableVendorValue()
	self:EnableEconomyFrame()
end

-- Handles disabling of the addon
function Analyst:OnDisable ()
	-- Subsystems
	self:DisableEconomyFrame()
	self:DisableVendorValue()
	self:DisableMeasure()
	self:DisableCapture()
end


----------------------------------------------------------------------
-- Events

-- Handles player login
function Analyst:PLAYER_LOGIN ()
	-- Binding
	if GetCurrentBindingSet() == ACCOUNT_BINDINGS then
		-- Account key bindings
		if not self.db.account.keysBound then
			self:BindKeys()
			self.db.account.keysBound = true
		end
	elseif GetCurrentBindingSet() == CHARACTER_BINDINGS then
		-- Character key bindings
		if not self.db.char.keysBound then
			self:BindKeys()
			self.db.char.keysBound = true
		end
	end
	
	-- Subsystems
	self:PlayerLoginCapture()
end

-- Handles player logout
function Analyst:PLAYER_LOGOUT ()
	-- Subsystems
	self:PlayerLogoutCapture()
end
	

----------------------------------------------------------------------
-- Settings

-- Returns whether the Economy Frame is shown
function Analyst:IsEconomyFrameShown ()
	return EconomyFrame:IsShown()
end

-- Toggles the Economy Frame
function Analyst:ToggleEconomyFrame ()
	if EconomyFrame:IsShown() then
		HideUIPanel(EconomyFrame)
	else
		ShowUIPanel(EconomyFrame)
	end
end

-- Returns the start day of the week
function Analyst:GetStartDayOfWeek ()
	return self.db.account.startDayOfWeek
end

-- Sets the start day of the week
function Analyst:SetStartDayOfWeek (startDayOfWeek)
	self.db.account.startDayOfWeek = startDayOfWeek
end


----------------------------------------------------------------------
-- FuBar

-- Handles clicks
function Analyst:OnClick (button)
	self:ToggleEconomyFrame()
end


----------------------------------------------------------------------
-- Helpers

-- Returns today's date
function Analyst:GetDate ()
	local now = time()
	local components = date("*t", today)
	local seconds =	((components.hour * 60) + components.min) * 60 + components.sec
	return now - seconds + 43200
end

-- Applies key bindings
function Analyst:BindKeys ()
	if GetBindingAction("SHIFT-E") == "" then
		SetBinding("SHIFT-E", "ECONOMY")
	end
end




